@@ -11,7 +11,7 @@ print.mapbayests <- function(x, ...){
   NAME <- x$model@model
   nID <- length(x$arg.ofv.id)
   nOBS <- x$arg.ofv.id %>% map("idDV") %>% unname() %>% simplify() %>% length()
-  nETA <- n_eta(x$model)
+  nETA <- eta_length(x$model)
   ETA <- x$final_eta %>%
     bind_rows(.id = "ID") %>%
     as.data.frame() %>%
@@ -46,6 +46,8 @@ as.data.frame.mapbayests <- function(x, row.names = NULL, optional = FALSE, ...)
 #'
 #' @param x A \code{mapbayests} object.
 #' @param ... additional arguments (passed to \code{\link{augment.mapbayests}})
+#' @param PREDICTION plot either "IPRED", "PRED" or both.
+#'
 #' @return a `ggplot` object.
 #'
 #' @details
@@ -59,9 +61,10 @@ as.data.frame.mapbayests <- function(x, row.names = NULL, optional = FALSE, ...)
 #' plot(est, end = 48) +
 #'   ggplot2::labs(title = "Awesome prediction")
 #'
+#'
 #' @method plot mapbayests
 #' @export
-plot.mapbayests <- function(x, ...){
+plot.mapbayests <- function(x, ..., PREDICTION = c("IPRED", "PRED")){
   #  if(!inherits(x, "mapbayests")) stop("Provided object is not a mapbayests class object")
 
   if(is.null(x$aug_tab)){
@@ -77,6 +80,7 @@ plot.mapbayests <- function(x, ...){
   }
 
   predictions <- x$aug_tab %>%
+    filter(.data$type %in% PREDICTION) %>%
     mutate(PREDICTION  = .data$type)
 
   gg <- predictions %>%
@@ -116,17 +120,17 @@ plot.mapbayests <- function(x, ...){
 
   if(all(!one_cmt, !one_ID)) {
     gg <- gg+
-      facet_grid(rows = vars(.data$ID), cols = vars(.data$cmt), scales = "free", labeller = label_both)
+      facet_grid(ID~cmt, scales = "free", labeller = label_both)
   }
 
   if(all(one_cmt, !one_ID)) {
     gg <- gg+
-      facet_grid(rows = vars(.data$ID), scales = "free", labeller = label_both)
+      facet_grid(ID~., scales = "free", labeller = label_both)
   }
 
   if(all(!one_cmt, one_ID)) {
     gg <- gg+
-      facet_grid(cols = vars(.data$cmt), scales = "free", labeller = label_both)
+      facet_grid(.~cmt, scales = "free", labeller = label_both)
   }
 
   return(gg)
@@ -252,12 +256,12 @@ augment.mapbayests <- function(x, data = NULL, start = NULL, end = NULL, delta =
   }
 
   if(is.null(start)){
-    start <- unname(map_dbl(idata, ~ min(.x$time)))
+    start <- unname(sapply(idata, function(x) min(x$time)))
     #A vector. For each ID, possibly a different start time.
   }
 
   if(is.null(end)){
-    end <- unname(map_dbl(idata, ~ max(.x$time)))
+    end <- unname(sapply(idata, function(x) max(x$time)))
     #A vector. For each ID, possibly a different end time.
     end <- end * 1.2
     #By default, +20% of last obs or dosing.
@@ -350,12 +354,12 @@ augment.mapbayests <- function(x, data = NULL, start = NULL, end = NULL, delta =
 }
 
 data_nid <- function(data, n){
-  map_dfr(.x = seq_len(n), ~mutate(data, ID = .x))
+  bind_rows(lapply(seq_len(n), function(x) mutate(data, ID = x)))
 }
 
 prepare_summarise <- function(data){
   data %>%
     group_by(.data$ID) %>%
-    mutate(rowID = row_number()) %>%
+    mutate(rowID = rank(.data$ID, ties.method = "first")) %>%
     group_by(.data$rowID)
 }
