@@ -1,5 +1,6 @@
 nmphi <- read_nmphi(system.file("nm001", "run001.phi", package = "mapbayr"))
 merged <- merge_phi(mapbayr_phi = get_phi(est001), nonmem_phi = nmphi)
+summarised <- summarise_phi(merged)
 
 test_that("read_nmphi works", {
   expect_equal(nrow(nmphi), 8)
@@ -40,3 +41,23 @@ test_that("plot_phi works", {
   x_labels <- ggplot2::ggplot_build(p)$layout$panel_params[[1]]$x$get_labels()
   expect_equal(x_labels, c("ETA1", "ETA2", "ETA3"))
 })
+
+test_that("summarise_phi works", {
+  expect_named(summarised, c("Performance", "count", "prop", "perc"))
+  expect_equal(levels(summarised$Performance), c("Excellent", "Acceptable", "Discordant"))
+
+  merge3 <- dplyr::bind_rows(merged, merged, merged, .id = "RUN")
+  summarised3 <- summarise_phi(merge3, group = RUN)
+  expect_named(summarised3, c("RUN", "Performance", "count", "prop", "perc"))
+})
+
+test_that("bar_phi works", {
+  p <- bar_phi(summarised)
+  expect_s3_class(p, "ggplot")
+})
+
+test_that("classify works", {
+  expect_equal(as.character(classify(c(0.0000001, 0.01, 1))), c("Excellent", "Acceptable", "Discordant"))
+  cla <- classify(c(0.0000001, 0.00002, 0.005, 1), levels = c(awesome = 0, nice = 0.00001, bad = 0.01))
+  expect_equal(as.character(cla), c("awesome", "nice", "nice", "bad"))
+})
